src/jdk.incubator.adba/share/classes/jdk/incubator/sql2/Session.java
branchJDK-8188051-branch
changeset 56828 64304e37e9b1
parent 56824 62e92191354d
child 56832 4f7713e6a308
--- a/src/jdk.incubator.adba/share/classes/jdk/incubator/sql2/Session.java	Wed Jul 11 19:30:26 2018 -0400
+++ b/src/jdk.incubator.adba/share/classes/jdk/incubator/sql2/Session.java	Wed Jul 11 19:36:23 2018 -0400
@@ -455,32 +455,32 @@
   public <S, T> OperationGroup<S, T> operationGroup();
 
   /**
    * Returns a new {@link TransactionEnd} that can be used as an argument to an
    * endTransaction Operation.
    *
    * It is most likely an error to call this within an error handler, or any
    * handler as it is very likely that when the handler is executed the next
    * submitted endTransaction {@link Operation} will have been created with a 
-   * different TransactionEnd.
+ different TransactionCompletion.
  
  ISSUE: Should this be moved to OperationGroup?
    *
    * @return a new {@link TransactionEnd}. Not null.
    * @throws IllegalStateException if this Session is not active
    */
-  public TransactionEnd transactionEnd();
+  public TransactionCompletion transactionCompletion();
   
   /**
    * Unconditionally perform a transaction rollback. Create an endTransaction 
    * {@link Operation}, set it to rollback only, and submit it. The endTransaction
    * is never skipped. Convenience method. To execute a commit call 
-   * {@link OperationGroup#commitMaybeRollback(jdk.incubator.sql2.TransactionEnd)}.
+   * {@link OperationGroup#commitMaybeRollback(jdk.incubator.sql2.TransactionCompletion)}.
    *
    * @return this {@link OperationGroup}
-   * @see OperationGroup#commitMaybeRollback(jdk.incubator.sql2.TransactionEnd) 
+   * @see OperationGroup#commitMaybeRollback(jdk.incubator.sql2.TransactionCompletion) 
    */
   public default CompletionStage<TransactionOutcome> rollback() {
-    TransactionEnd t = transactionEnd();
+    TransactionCompletion t = transactionCompletion();
     t.setRollbackOnly();
     catchErrors();
     return this.endTransactionOperation(t).submit().getCompletionStage();
@@ -455,32 +455,32 @@
 
   /**
-   * Returns a new {@link TransactionEnd} that can be used as an argument to an
+   * Returns a new {@link TransactionCompletion} that can be used as an argument to an
    * endTransaction Operation.
    *
@@ -455,32 +455,32 @@
  ISSUE: Should this be moved to OperationGroup?
    *
-   * @return a new {@link TransactionEnd}. Not null.
+   * @return a new {@link TransactionCompletion}. Not null.
    * @throws IllegalStateException if this Session is not active
    */